@@ -7,14 +7,14 @@
     'name_es_CO': 'Terceros',
     'name_es_ES': 'Terceros',
     'name_fr_FR': 'Tiers',
-    'version' : '1.2.0',
+    'version' : '1.4.1',
     'author' : 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
     'description': 'Define parties, addresses and co.',
     'description_de_DE': 'Ermöglicht die Erstellung von Parteien, Adressen, etc.',
     'description_es_CO': 'Definición de terceros, direcciones, etc.',
-    'description_es_ES': 'Definición de terceros, direcciones, etc.',
+    'description_es_ES': 'Define terceros, direcciones, etc...',
     'description_fr_FR': 'Définit des tiers, des adresses, etc.',
     'depends' : [
         'ir',
